@@ -667,7 +667,7 @@ try {
             }
             
             // Run the scheduler script
-            $scriptPath = dirname(__DIR__) . '/scripts/backup-scheduler.php';
+            $scriptPath = '/root/whp/scripts/backup-scheduler.php';
             if (!file_exists($scriptPath)) {
                 throw new Exception('Scheduler script not found');
             }
