@@ -424,10 +424,19 @@ try {
                 throw new Exception('Permission denied');
             }
 
-            // Get domain for backup filtering
+            // Get domain and container for backup filtering
             $domain = $site['domain'];
+            $containerName = $site['container_name'];
 
-            // Query backups for this domain
+            // Escape LIKE wildcards to prevent SQL injection
+            $escapedDomain = str_replace(['\\', '%', '_'], ['\\\\', '\\%', '\\_'], $domain);
+            $escapedContainer = str_replace(['\\', '%', '_'], ['\\\\', '\\%', '\\_'], $containerName);
+
+            // Query backups for this domain - include all relevant backup types
+            // wordpress: auto WordPress backups
+            // site: full site backups (may contain WordPress)
+            // database: database-only backups
+            // userfiles: files-only backups
             $stmt = $db->prepare("
                 SELECT
                     bh.id,
@@ -440,24 +449,40 @@ try {
                     bh.started_at,
                     bh.completed_at,
                     bh.local_path,
-                    bh.local_deleted_at
+                    bh.local_deleted_at,
+                    bh.metadata
                 FROM backup_history bh
                 WHERE bh.user = ?
-                AND bh.backup_name LIKE ?
-                AND bh.backup_type = 'wordpress'
+                AND (
+                    bh.backup_name LIKE ?
+                    OR bh.backup_name LIKE ?
+                )
+                AND bh.backup_type IN ('wordpress', 'site', 'database', 'userfiles')
                 AND bh.status = 'completed'
                 ORDER BY bh.started_at DESC
-                LIMIT 50
+                LIMIT 100
             ");
-            $stmt->execute([$site['user'], '%' . $domain . '%']);
+            $stmt->execute([
+                $site['user'],
+                '%' . $escapedDomain . '%',
+                '%' . $escapedContainer . '%'
+            ]);
             $backups = $stmt->fetchAll(PDO::FETCH_ASSOC);
 
+            // Decode metadata for each backup
+            foreach ($backups as &$backup) {
+                if (!empty($backup['metadata']) && is_string($backup['metadata'])) {
+                    $backup['metadata'] = json_decode($backup['metadata'], true);
+                }
+            }
+
             ob_clean();
             echo json_encode(['success' => true, 'backups' => $backups]);
             exit;
 
         case 'restore_backup':
             // Restore WordPress from backup
+            // Supports multiple backup types: wordpress, site, database, userfiles
             $siteId = $_POST['site_id'] ?? '';
             $backupId = $_POST['backup_id'] ?? '';
 
@@ -494,7 +519,10 @@ try {
                 throw new Exception('Backup is not completed');
             }
 
-            // Restore the backup
+            // Log backup type for debugging
+            error_log("WordPress Restore: Restoring backup ID {$backupId}, type: {$backupData['backup_type']}");
+
+            // Restore the backup (method will route based on backup_type)
             $result = $wpManager->restoreWordPressBackup(
                 $site['container_name'],
                 $site['user'],
