@@ -378,6 +378,13 @@ class MailServerClient {
         return $this->makeRequest('GET', "domains/$domain_name/dkim");
     }
     
+    /**
+     * Delete DKIM records for a domain
+     */
+    public function deleteDkimRecords($domain_name) {
+        return $this->makeRequest('DELETE', "domains/$domain_name/dkim");
+    }
+    
     /**
      * Update email account quota
      */
