@@ -1094,7 +1094,10 @@ SSLCryptoDevice builtin
 
     /**
      * Refresh system service SSL certificate from HAProxy
-     * This method copies the latest certificate from HAProxy and restarts the service
+     *
+     * This method copies the existing certificate from HAProxy container to the host
+     * and restarts the system service. It does NOT trigger a certificate renewal.
+     * HAProxy automatically renews Let's Encrypt certificates - this just syncs them.
      *
      * @param string $service_name Service name
      * @param string $domain Domain name
@@ -1134,17 +1137,21 @@ SSLCryptoDevice builtin
                 ];
             }
 
-            // Request certificate renewal from HAProxy (this regenerates the PEM file)
-            error_log("SSL Manager: Requesting certificate renewal from HAProxy for {$domain}");
-            $result = $this->haproxy_manager->renewCertificate($domain);
+            // Request HAProxy to regenerate the combined PEM file for this domain
+            // This doesn't trigger Let's Encrypt renewal, just recreates the combined cert+key file
+            error_log("SSL Manager: Requesting certificate file regeneration from HAProxy for {$domain}");
+            $result = $this->haproxy_manager->requestCertificate($domain, false, false);
 
             if (!$result['success']) {
-                error_log("SSL Manager: HAProxy renewal failed: " . ($result['error'] ?? 'Unknown error'));
-                return $result;
+                error_log("SSL Manager: HAProxy certificate request failed: " . ($result['error'] ?? 'Unknown error'));
+                // If request failed, try to copy existing certificate anyway
+                error_log("SSL Manager: Attempting to copy existing certificate anyway for {$domain}");
+            } else {
+                error_log("SSL Manager: HAProxy certificate file regenerated successfully for {$domain}");
+                // Wait briefly for file to be written
+                sleep(1);
             }
 
-            error_log("SSL Manager: HAProxy renewal successful, copying certificate from container");
-
             // Create certificate directory if it doesn't exist
             $cert_dir = "/etc/certs";
             if (!is_dir($cert_dir)) {
@@ -1160,8 +1167,7 @@ SSLCryptoDevice builtin
             $container_cert_path = "/etc/haproxy/certs/{$domain}.pem";
             $host_cert_path = "{$cert_dir}/{$domain}.pem";
 
-            // Wait for the certificate to be regenerated
-            sleep(2);
+            error_log("SSL Manager: Copying certificate from HAProxy container for {$domain}");
 
             // Check if certificate exists in container
             $safe_container_path = escapeshellarg($container_cert_path);
