@@ -327,7 +327,7 @@ foreach ($users as $user) {
                     <div class="mb-3">
                         <label for="edit_max_disk" class="form-label">Max Disk Space (MB)</label>
                         <input type="number" class="form-control" id="edit_max_disk" name="max_disk_space" 
-                               min="100" max="100000" step="100" required>
+                               min="100" max="100000" required>
                     </div>
                     
                     <div class="mb-3">
@@ -339,7 +339,7 @@ foreach ($users as $user) {
                     <div class="mb-3">
                         <label for="edit_max_email_storage" class="form-label">Max Email Storage (MB)</label>
                         <input type="number" class="form-control" id="edit_max_email_storage" name="max_email_storage_mb" 
-                               min="0" max="100000" step="100" required>
+                               min="0" max="100000" required>
                         <div class="form-text">Total storage limit for all email accounts combined</div>
                     </div>
                 </div>
